#
# PySNMP MIB module ADSL-LINE-EXT-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ADSL-LINE-EXT-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:04:05 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( adslAtucIntervalEntry, adslLineAlarmConfProfileEntry, adslAtucPerfDataEntry, adslAturIntervalEntry, adslAturPerfDataEntry, adslLineConfProfileEntry, adslMIB, adslLineEntry, ) = mibBuilder.importSymbols("ADSL-LINE-MIB", "adslAtucIntervalEntry", "adslLineAlarmConfProfileEntry", "adslAtucPerfDataEntry", "adslAturIntervalEntry", "adslAturPerfDataEntry", "adslLineConfProfileEntry", "adslMIB", "adslLineEntry")
( AdslPerfPrevDayCount, AdslPerfCurrDayCount, ) = mibBuilder.importSymbols("ADSL-TC-MIB", "AdslPerfPrevDayCount", "AdslPerfCurrDayCount")
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection")
( PerfIntervalCount, PerfCurrentCount, ) = mibBuilder.importSymbols("PerfHist-TC-MIB", "PerfIntervalCount", "PerfCurrentCount")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Counter64, ObjectIdentity, TimeTicks, iso, Integer32, MibIdentifier, Gauge32, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, IpAddress, Counter32, Unsigned32, NotificationType, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter64", "ObjectIdentity", "TimeTicks", "iso", "Integer32", "MibIdentifier", "Gauge32", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "IpAddress", "Counter32", "Unsigned32", "NotificationType", "ModuleIdentity")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
adslExtMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 94, 3)).setRevisions(("2002-12-10 00:00",))
if mibBuilder.loadTexts: adslExtMIB.setLastUpdated('200212100000Z')
if mibBuilder.loadTexts: adslExtMIB.setOrganization('IETF ADSL MIB Working Group')
if mibBuilder.loadTexts: adslExtMIB.setContactInfo('\n          Faye Ly\n          Pedestal Networks\n          6503 Dumbarton Circle,\n          Fremont, CA 94555\n          Tel: +1 510-578-0158\n          Fax: +1 510-744-5152\n          E-Mail: faye@pedestalnetworks.com\n\n          Gregory Bathrick\n          Nokia Networks\n          2235 Mercury Way,\n          Fax: +1 707-535-7300\n          E-Mail: greg.bathrick@nokia.com\n\n          General Discussion:adslmib@ietf.org\n          To Subscribe: https://www1.ietf.org/mailman/listinfo/adslmib\n          Archive: https://www1.ietf.org/mailman/listinfo/adslmib\n          ')
if mibBuilder.loadTexts: adslExtMIB.setDescription('Copyright (C) The Internet Society (2002). This version of\n           this MIB module is part of RFC 3440; see the RFC itself for\n           full legal notices.\n\n           This MIB Module is a supplement to the ADSL-LINE-MIB\n           [RFC2662].')
adslExtMibObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 1))
class AdslTransmissionModeType(Bits, TextualConvention):
    namedValues = NamedValues(("ansit1413", 0), ("etsi", 1), ("q9921PotsNonOverlapped", 2), ("q9921PotsOverlapped", 3), ("q9921IsdnNonOverlapped", 4), ("q9921isdnOverlapped", 5), ("q9921tcmIsdnNonOverlapped", 6), ("q9921tcmIsdnOverlapped", 7), ("q9922potsNonOverlapeed", 8), ("q9922potsOverlapped", 9), ("q9922tcmIsdnNonOverlapped", 10), ("q9922tcmIsdnOverlapped", 11), ("q9921tcmIsdnSymmetric", 12),)

adslLineExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17), )
if mibBuilder.loadTexts: adslLineExtTable.setDescription("This table is an extension of RFC 2662.  It\n                  contains ADSL line configuration and\n                  monitoring information. This includes the ADSL\n                  line's capabilities and actual ADSL transmission\n                  system.")
adslLineExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17, 1), )
adslLineEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslLineExtEntry"))
adslLineExtEntry.setIndexNames(*adslLineEntry.getIndexNames())
if mibBuilder.loadTexts: adslLineExtEntry.setDescription('An entry extends the adslLineEntry defined in\n                  [RFC2662].  Each entry corresponds to an ADSL\n                  line.')
adslLineTransAtucCap = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17, 1, 1), AdslTransmissionModeType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: adslLineTransAtucCap.setDescription('The transmission modes, represented by a\n                  bitmask that the ATU-C is capable of\n                  supporting.  The modes available are limited\n                  by the design of the equipment.')
adslLineTransAtucConfig = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17, 1, 2), AdslTransmissionModeType()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: adslLineTransAtucConfig.setDescription("The transmission modes, represented by a bitmask,\n                  currently enabled by the ATU-C.  The manager can\n                  only set those modes that are supported by the\n\n\n                  ATU-C.  An ATU-C's supported modes are provided by\n                  AdslLineTransAtucCap.")
adslLineTransAtucActual = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17, 1, 3), AdslTransmissionModeType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: adslLineTransAtucActual.setDescription("The actual transmission mode of the ATU-C.\n                  During ADSL line initialization, the ADSL\n                  Transceiver Unit - Remote terminal end (ATU-R)\n                  will determine the mode used for the link.\n                  This value will be limited a single transmission\n                  mode that is a subset of those modes enabled\n                  by the ATU-C and denoted by\n                  adslLineTransAtucConfig. After an initialization\n                  has occurred, its mode is saved as the 'Current'\n                  mode and is persistence should the link go\n                  down. This object returns 0 (i.e. BITS with no\n                  mode bit set) if the mode is not known.")
adslLineGlitePowerState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("l0", 2), ("l1", 3), ("l3", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: adslLineGlitePowerState.setDescription('The value of this object specifies the power\n                  state of this interface.  L0 is power on, L1 is\n                  power on but reduced and L3 is power off.  Power\n                  state cannot be configured by an operator but it\n                  can be viewed via the ifOperStatus object for the\n                  managed ADSL interface.  The value of the object\n                  ifOperStatus is set to down(2) if the ADSL\n                  interface is in power state L3 and is set to up(1)\n                  if the ADSL line interface is in power state L0 or\n                  L1. If the object adslLineTransAtucActual is set to\n                  a G.992.2 (G.Lite)-type transmission mode, the\n                  value of this object will be one of the valid power\n                  states: L0(2), L1(3), or L3(4).  Otherwise, its\n\n\n                  value will be none(1).')
adslLineConfProfileDualLite = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 17, 1, 5), SnmpAdminString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: adslLineConfProfileDualLite.setDescription("This object extends the definition an ADSL line and\n                  associated channels (when applicable) for cases\n                  when it is configured in dual mode, and operating\n                  in a G.Lite-type mode as denoted by\n                  adslLineTransAtucActual.  Dual mode exists when the\n                  object, adslLineTransAtucConfig, is configured with\n                  one or more full-rate modes and one or more G.Lite\n                  modes simultaneously.\n\n                  When 'dynamic' profiles are implemented, the value\n                  of object is equal to the index of the applicable\n                  row in the ADSL Line Configuration Profile Table,\n                  AdslLineConfProfileTable defined in ADSL-MIB\n                  [RFC2662].\n\n                  In the case when dual-mode has not been enabled,\n                  the value of the object will be equal to the value\n                  of the object adslLineConfProfile [RFC2662].\n\n                  When `static' profiles are implemented, in much\n                  like the case of the object,\n                  adslLineConfProfileName [RFC2662], this object's\n                  value will need to algorithmically represent the\n                  characteristics of the line.  In this case, the\n                  value of the line's ifIndex plus a value indicating\n                  the line mode type (e.g., G.Lite, Full-rate) will\n                  be used. Therefore, the profile's name is a string\n                  concatenating the ifIndex and one of the follow\n                  values: Full or Lite. This string will be\n                  fixed-length (i.e., 14) with leading zero(s).  For\n                  example, the profile name for ifIndex that equals\n                  '15' and is a full rate line, it will be\n                  '0000000015Full'.")
adslAtucPerfDataExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18), )
if mibBuilder.loadTexts: adslAtucPerfDataExtTable.setDescription('This table extends adslAtucPerfDataTable [RFC2662]\n                  with additional ADSL physical line counter\n                  information such as unavailable seconds-line and\n                  severely errored seconds-line.')
adslAtucPerfDataExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1), )
adslAtucPerfDataEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslAtucPerfDataExtEntry"))
adslAtucPerfDataExtEntry.setIndexNames(*adslAtucPerfDataEntry.getIndexNames())
if mibBuilder.loadTexts: adslAtucPerfDataExtEntry.setDescription('An entry extends the adslAtucPerfDataEntry defined\n                  in [RFC2662].  Each entry corresponds to an ADSL\n                  line.')
adslAtucPerfStatFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 1), Counter32()).setUnits('line retrains').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfStatFastR.setDescription('The value of this object reports the count of\n                  the number of fast line bs since last\n                  agent reset.')
adslAtucPerfStatFailedFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 2), Counter32()).setUnits('line retrains').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfStatFailedFastR.setDescription('The value of this object reports the count of\n                  the number of failed fast line retrains since\n                  last agent reset.')
adslAtucPerfStatSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 3), Counter32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfStatSesL.setDescription('The value of this object reports the count of\n                  the number of severely errored seconds-line since\n                  last agent reset.')
adslAtucPerfStatUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 4), Counter32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfStatUasL.setDescription('The value of this object reports the count of\n                  the number of unavailable seconds-line since\n                  last agent reset.')
adslAtucPerfCurr15MinFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 5), PerfCurrentCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr15MinFastR.setDescription('For the current 15-minute interval,\n                  adslAtucPerfCurr15MinFastR reports the current\n                  number of seconds during which there have been\n\n\n                  fast retrains.')
adslAtucPerfCurr15MinFailedFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 6), PerfCurrentCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr15MinFailedFastR.setDescription('For the current 15-minute interval,\n                  adslAtucPerfCurr15MinFailedFastR reports the\n                  current number of seconds during which there\n                  have been failed fast retrains.')
adslAtucPerfCurr15MinSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 7), PerfCurrentCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr15MinSesL.setDescription('For the current 15-minute interval,\n                  adslAtucPerfCurr15MinSesL reports the current\n                  number of seconds during which there have been\n                  severely errored seconds-line.')
adslAtucPerfCurr15MinUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 8), PerfCurrentCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr15MinUasL.setDescription('For the current 15-minute interval,\n                  adslAtucPerfCurr15MinUasL reports the current\n                  number of seconds during which there have been\n                  unavailable seconds-line.')
adslAtucPerfCurr1DayFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 9), AdslPerfCurrDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr1DayFastR.setDescription('For the current day as measured by\n                  adslAtucPerfCurr1DayTimeElapsed [RFC2662],\n                  adslAtucPerfCurr1DayFastR reports the number\n                  of seconds during which there have been\n                  fast retrains.')
adslAtucPerfCurr1DayFailedFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 10), AdslPerfCurrDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr1DayFailedFastR.setDescription('For the current day as measured by\n                  adslAtucPerfCurr1DayTimeElapsed [RFC2662],\n                  adslAtucPerfCurr1DayFailedFastR reports the\n                  number of seconds during which there have been\n                  failed fast retrains.')
adslAtucPerfCurr1DaySesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 11), AdslPerfCurrDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr1DaySesL.setDescription('For the current day as measured by\n                  adslAtucPerfCurr1DayTimeElapsed [RFC2662],\n                  adslAtucPerfCurr1DaySesL reports the\n                  number of seconds during which there have been\n                  severely errored seconds-line.')
adslAtucPerfCurr1DayUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 12), AdslPerfCurrDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfCurr1DayUasL.setDescription('For the current day as measured by\n                  adslAtucPerfCurr1DayTimeElapsed [RFC2662],\n                  adslAtucPerfCurr1DayUasL reports the\n                  number of seconds during which there have been\n                  unavailable seconds-line.')
adslAtucPerfPrev1DayFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 13), AdslPerfPrevDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfPrev1DayFastR.setDescription('For the previous day, adslAtucPerfPrev1DayFastR\n                  reports the number of seconds during which there\n                  were fast retrains.')
adslAtucPerfPrev1DayFailedFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 14), AdslPerfPrevDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfPrev1DayFailedFastR.setDescription('For the previous day,\n                  adslAtucPerfPrev1DayFailedFastR reports the number\n                  of seconds during which there were failed fast\n                  retrains.')
adslAtucPerfPrev1DaySesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 15), AdslPerfPrevDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfPrev1DaySesL.setDescription('For the previous day, adslAtucPerfPrev1DaySesL\n                  reports the number of seconds during which there\n                  were severely errored seconds-line.')
adslAtucPerfPrev1DayUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 18, 1, 16), AdslPerfPrevDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucPerfPrev1DayUasL.setDescription('For the previous day, adslAtucPerfPrev1DayUasL\n                  reports the number of seconds during which there\n\n\n                  were unavailable seconds-line.')
adslAtucIntervalExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 19), )
if mibBuilder.loadTexts: adslAtucIntervalExtTable.setDescription("This table provides one row for each ATU-C\n                  performance data collection interval for\n                  ADSL physical interfaces whose\n                  IfEntries' ifType is equal to adsl(94).")
adslAtucIntervalExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 19, 1), )
adslAtucIntervalEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslAtucIntervalExtEntry"))
adslAtucIntervalExtEntry.setIndexNames(*adslAtucIntervalEntry.getIndexNames())
if mibBuilder.loadTexts: adslAtucIntervalExtEntry.setDescription('An entry in the\n                              adslAtucIntervalExtTable.')
adslAtucIntervalFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 19, 1, 1), PerfIntervalCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucIntervalFastR.setDescription('For the current interval, adslAtucIntervalFastR\n                  reports the current number of seconds during which\n                  there have been fast retrains.')
adslAtucIntervalFailedFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 19, 1, 2), PerfIntervalCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucIntervalFailedFastR.setDescription('For the each interval, adslAtucIntervalFailedFastR\n                  reports the number of seconds during which\n                  there have been failed fast retrains.')
adslAtucIntervalSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 19, 1, 3), PerfIntervalCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucIntervalSesL.setDescription('For the each interval, adslAtucIntervalSesL\n                  reports the number of seconds during which\n                  there have been severely errored seconds-line.')
adslAtucIntervalUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 19, 1, 4), PerfIntervalCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAtucIntervalUasL.setDescription('For the each interval, adslAtucIntervalUasL\n                  reports the number of seconds during which\n                  there have been unavailable seconds-line.')
adslAturPerfDataExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20), )
if mibBuilder.loadTexts: adslAturPerfDataExtTable.setDescription('This table contains ADSL physical line counters\n                  not defined in the adslAturPerfDataTable\n                  from the ADSL-LINE-MIB [RFC2662].')
adslAturPerfDataExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1), )
adslAturPerfDataEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslAturPerfDataExtEntry"))
adslAturPerfDataExtEntry.setIndexNames(*adslAturPerfDataEntry.getIndexNames())
if mibBuilder.loadTexts: adslAturPerfDataExtEntry.setDescription('An entry extends the adslAturPerfDataEntry defined\n                  in [RFC2662].  Each entry corresponds to an ADSL\n                  line.')
adslAturPerfStatSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 1), Counter32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfStatSesL.setDescription('The value of this object reports the count of\n                  severely errored second-line since the last agent\n                  reset.')
adslAturPerfStatUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 2), Counter32()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfStatUasL.setDescription('The value of this object reports the count of\n                  unavailable seconds-line since the last agent\n                  reset.')
adslAturPerfCurr15MinSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 3), PerfCurrentCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfCurr15MinSesL.setDescription('For the current 15-minute interval,\n                  adslAturPerfCurr15MinSesL reports the current\n                  number of seconds during which there have been\n                  severely errored seconds-line.')
adslAturPerfCurr15MinUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 4), PerfCurrentCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfCurr15MinUasL.setDescription('For the current 15-minute interval,\n                  adslAturPerfCurr15MinUasL reports the current\n                  number of seconds during which there have been\n                  available seconds-line.')
adslAturPerfCurr1DaySesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 5), AdslPerfCurrDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfCurr1DaySesL.setDescription('For the current day as measured by\n                  adslAturPerfCurr1DayTimeElapsed [RFC2662],\n                  adslAturPerfCurr1DaySesL reports the\n                  number of seconds during which there have been\n                  severely errored seconds-line.')
adslAturPerfCurr1DayUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 6), AdslPerfCurrDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfCurr1DayUasL.setDescription('For the current day as measured by\n                  adslAturPerfCurr1DayTimeElapsed [RFC2662],\n                  adslAturPerfCurr1DayUasL reports the\n                  number of seconds during which there have been\n                  unavailable seconds-line.')
adslAturPerfPrev1DaySesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 7), AdslPerfPrevDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfPrev1DaySesL.setDescription('For the previous day, adslAturPerfPrev1DaySesL\n                  reports the number of seconds during which there\n                  were severely errored seconds-line.')
adslAturPerfPrev1DayUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 20, 1, 8), AdslPerfPrevDayCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturPerfPrev1DayUasL.setDescription('For the previous day, adslAturPerfPrev1DayUasL\n                  reports the number of seconds during which there\n                  were severely errored seconds-line.')
adslAturIntervalExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 21), )
if mibBuilder.loadTexts: adslAturIntervalExtTable.setDescription("This table provides one row for each ATU-R\n                  performance data collection interval for\n                  ADSL physical interfaces whose\n                  IfEntries' ifType is equal to adsl(94).")
adslAturIntervalExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 21, 1), )
adslAturIntervalEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslAturIntervalExtEntry"))
adslAturIntervalExtEntry.setIndexNames(*adslAturIntervalEntry.getIndexNames())
if mibBuilder.loadTexts: adslAturIntervalExtEntry.setDescription('An entry in the\n                              adslAturIntervalExtTable.')
adslAturIntervalSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 21, 1, 1), PerfIntervalCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturIntervalSesL.setDescription('For the each interval, adslAturIntervalSesL\n                  reports the number of seconds during which\n                  there have been severely errored seconds-line.')
adslAturIntervalUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 21, 1, 2), PerfIntervalCount()).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: adslAturIntervalUasL.setDescription('For the each interval, adslAturIntervalUasL\n                  reports the number of seconds during which\n                  there have been unavailable seconds-line.')
adslConfProfileExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 22), )
if mibBuilder.loadTexts: adslConfProfileExtTable.setDescription('The adslConfProfileExtTable extends the ADSL line\n                  profile configuration information in the\n                  adslLineConfProfileTable from the ADSL-LINE-MIB\n                  [RFC2662] by adding the ability to configure the\n                  ADSL physical line mode.')
adslConfProfileExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 22, 1), )
adslLineConfProfileEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslConfProfileExtEntry"))
adslConfProfileExtEntry.setIndexNames(*adslLineConfProfileEntry.getIndexNames())
if mibBuilder.loadTexts: adslConfProfileExtEntry.setDescription('An entry extends the adslLineConfProfileEntry\n                  defined in [RFC2662].  Each entry corresponds to an\n                  ADSL line profile.')
adslConfProfileLineType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 22, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("noChannel", 1), ("fastOnly", 2), ("interleavedOnly", 3), ("fastOrInterleaved", 4), ("fastAndInterleaved", 5),)).clone('fastOnly')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: adslConfProfileLineType.setDescription('This object is used to configure the ADSL physical\n                  line mode.  It has following valid values:\n\n                  noChannel(1), when no channels exist.\n                  fastOnly(2), when only fast channel exists.\n                  interleavedOnly(3), when only interleaved channel\n                      exist.\n                  fastOrInterleaved(4), when either fast or\n                      interleaved channels can exist, but only one\n                      at any time.\n                  fastAndInterleaved(5), when both the fast channel\n                      and the interleaved channel exist.\n\n                  In the case when no value has been set, the default\n                  Value is noChannel(1).\n                  ')
adslAlarmConfProfileExtTable = MibTable((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23), )
if mibBuilder.loadTexts: adslAlarmConfProfileExtTable.setDescription('This table extends the\n                  adslLineAlarmConfProfileTable and provides\n                  threshold parameters for all the counters defined\n                  in this MIB module.')
adslAlarmConfProfileExtEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23, 1), )
adslLineAlarmConfProfileEntry.registerAugmentions(("ADSL-LINE-EXT-MIB", "adslAlarmConfProfileExtEntry"))
adslAlarmConfProfileExtEntry.setIndexNames(*adslLineAlarmConfProfileEntry.getIndexNames())
if mibBuilder.loadTexts: adslAlarmConfProfileExtEntry.setDescription('An entry extends the adslLineAlarmConfProfileTable\n                  defined in [RFC2662].  Each entry corresponds to\n                  an ADSL alarm profile.')
adslAtucThreshold15MinFailedFastR = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,900))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: adslAtucThreshold15MinFailedFastR.setDescription("The first time the value of the corresponding\n                  instance of adslAtucPerfCurr15MinFailedFastR\n                  reaches or exceeds this value within a given\n                  15-minute performance data collection period,\n                  an adslAtucFailedFastRThreshTrap  notification\n                  will be generated. The value '0' will disable\n                  the notification. The default value of this\n                  object is '0'.")
adslAtucThreshold15MinSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,900))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: adslAtucThreshold15MinSesL.setDescription("The first time the value of the corresponding\n                  instance of adslAtucPerf15MinSesL reaches or\n                  exceeds this value within a given 15-minute\n                  performance data collection period, an\n                  adslAtucSesLThreshTrap notification will be\n                  generated. The value '0' will disable the\n                  notification.  The default value of this\n                  object is '0'.")
adslAtucThreshold15MinUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,900))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: adslAtucThreshold15MinUasL.setDescription("The first time the value of the corresponding\n                  instance of adslAtucPerf15MinUasL reaches or\n                  exceeds this value within a given 15-minute\n                  performance data collection period, an\n                  adslAtucUasLThreshTrap notification will be\n                  generated. The value '0' will disable the\n                  notification.  The default value of this\n                  object is '0'.")
adslAturThreshold15MinSesL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,900))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: adslAturThreshold15MinSesL.setDescription("The first time the value of the corresponding\n                  instance of adslAturPerf15MinSesL reaches or\n                  exceeds this value within a given 15-minute\n                  performance data collection period, an\n                  adslAturSesLThreshTrap notification will be\n                  generated. The value '0' will disable the\n                  notification.  The default value of this\n                  object is '0'.")
adslAturThreshold15MinUasL = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 23, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,900))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: adslAturThreshold15MinUasL.setDescription("The first time the value of the corresponding\n                  instance of adslAturPerf15MinUasL reaches or\n                  exceeds this value within a given 15-minute\n                  performance data collection period, an\n\n\n                  adslAturUasLThreshTrap notification will be\n                  generated. The value '0' will disable the\n                  notification.  The default value of this\n                  object is '0'.")
adslExtTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24))
adslExtAtucTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 1))
adslExtAtucTrapsPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 1, 0))
adslAtucFailedFastRThreshTrap = NotificationType((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 1, 0, 1)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinFailedFastR"),))
if mibBuilder.loadTexts: adslAtucFailedFastRThreshTrap.setDescription('Failed Fast Retrains 15-minute threshold reached.')
adslAtucSesLThreshTrap = NotificationType((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 1, 0, 2)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinSesL"),))
if mibBuilder.loadTexts: adslAtucSesLThreshTrap.setDescription('Severely errored seconds-line 15-minute threshold\n                  reached.')
adslAtucUasLThreshTrap = NotificationType((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 1, 0, 3)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinUasL"),))
if mibBuilder.loadTexts: adslAtucUasLThreshTrap.setDescription('Unavailable seconds-line 15-minute threshold\n                  reached.')
adslExtAturTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 2))
adslExtAturTrapsPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 2, 0))
adslAturSesLThreshTrap = NotificationType((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 2, 0, 1)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAturPerfCurr15MinSesL"),))
if mibBuilder.loadTexts: adslAturSesLThreshTrap.setDescription('Severely errored seconds-line 15-minute threshold\n                  reached.')
adslAturUasLThreshTrap = NotificationType((1, 3, 6, 1, 2, 1, 10, 94, 3, 1, 24, 2, 0, 2)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAturPerfCurr15MinUasL"),))
if mibBuilder.loadTexts: adslAturUasLThreshTrap.setDescription('Unavailable seconds-line 15-minute threshold\n                  reached.')
adslExtConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 2))
adslExtGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1))
adslExtCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 2))
adslExtLineMibAtucCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 2, 1)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslExtLineGroup"), ("ADSL-LINE-EXT-MIB", "adslExtLineConfProfileControlGroup"), ("ADSL-LINE-EXT-MIB", "adslExtLineAlarmConfProfileGroup"), ("ADSL-LINE-EXT-MIB", "adslExtAtucPhysPerfCounterGroup"), ("ADSL-LINE-EXT-MIB", "adslExtAturPhysPerfCounterGroup"), ("ADSL-LINE-EXT-MIB", "adslExtNotificationsGroup"),))
if mibBuilder.loadTexts: adslExtLineMibAtucCompliance.setDescription('The compliance statement for SNMP entities which\n                  represent ADSL ATU-C interfaces.')
adslExtLineGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1, 1)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslLineConfProfileDualLite"), ("ADSL-LINE-EXT-MIB", "adslLineTransAtucCap"), ("ADSL-LINE-EXT-MIB", "adslLineTransAtucConfig"), ("ADSL-LINE-EXT-MIB", "adslLineTransAtucActual"), ("ADSL-LINE-EXT-MIB", "adslLineGlitePowerState"),))
if mibBuilder.loadTexts: adslExtLineGroup.setDescription('A collection of objects providing extended\n                 configuration information about an ADSL Line.')
adslExtAtucPhysPerfCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1, 2)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAtucPerfStatFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfStatFailedFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinFailedFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr1DayFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr1DayFailedFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfPrev1DayFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfPrev1DayFailedFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfStatSesL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfStatUasL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinSesL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr15MinUasL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr1DaySesL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfCurr1DayUasL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfPrev1DaySesL"), ("ADSL-LINE-EXT-MIB", "adslAtucPerfPrev1DayUasL"), ("ADSL-LINE-EXT-MIB", "adslAtucIntervalFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucIntervalFailedFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucIntervalSesL"), ("ADSL-LINE-EXT-MIB", "adslAtucIntervalUasL"),))
if mibBuilder.loadTexts: adslExtAtucPhysPerfCounterGroup.setDescription('A collection of objects providing raw performance\n                 counts on an ADSL Line (ATU-C end).')
adslExtAturPhysPerfCounterGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1, 3)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAturPerfStatSesL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfStatUasL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfCurr15MinSesL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfCurr15MinUasL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfCurr1DaySesL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfCurr1DayUasL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfPrev1DaySesL"), ("ADSL-LINE-EXT-MIB", "adslAturPerfPrev1DayUasL"), ("ADSL-LINE-EXT-MIB", "adslAturIntervalSesL"), ("ADSL-LINE-EXT-MIB", "adslAturIntervalUasL"),))
if mibBuilder.loadTexts: adslExtAturPhysPerfCounterGroup.setDescription('A collection of objects providing raw performance\n                 counts on an ADSL Line (ATU-C end).')
adslExtLineConfProfileControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1, 4)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslConfProfileLineType"),))
if mibBuilder.loadTexts: adslExtLineConfProfileControlGroup.setDescription('A collection of objects providing profile\n                 control for the ADSL system.')
adslExtLineAlarmConfProfileGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1, 5)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAtucThreshold15MinFailedFastR"), ("ADSL-LINE-EXT-MIB", "adslAtucThreshold15MinSesL"), ("ADSL-LINE-EXT-MIB", "adslAtucThreshold15MinUasL"), ("ADSL-LINE-EXT-MIB", "adslAturThreshold15MinSesL"), ("ADSL-LINE-EXT-MIB", "adslAturThreshold15MinUasL"),))
if mibBuilder.loadTexts: adslExtLineAlarmConfProfileGroup.setDescription('A collection of objects providing alarm profile\n                 control for the ADSL system.')
adslExtNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 94, 3, 2, 1, 6)).setObjects(*(("ADSL-LINE-EXT-MIB", "adslAtucFailedFastRThreshTrap"), ("ADSL-LINE-EXT-MIB", "adslAtucSesLThreshTrap"), ("ADSL-LINE-EXT-MIB", "adslAtucUasLThreshTrap"), ("ADSL-LINE-EXT-MIB", "adslAturSesLThreshTrap"), ("ADSL-LINE-EXT-MIB", "adslAturUasLThreshTrap"),))
if mibBuilder.loadTexts: adslExtNotificationsGroup.setDescription('The collection of ADSL extension notifications.')
mibBuilder.exportSymbols("ADSL-LINE-EXT-MIB", adslAtucPerfStatFastR=adslAtucPerfStatFastR, adslLineTransAtucActual=adslLineTransAtucActual, adslAtucPerfStatSesL=adslAtucPerfStatSesL, adslLineExtTable=adslLineExtTable, adslAtucPerfPrev1DaySesL=adslAtucPerfPrev1DaySesL, adslExtAturTrapsPrefix=adslExtAturTrapsPrefix, adslLineTransAtucCap=adslLineTransAtucCap, adslAtucPerfDataExtEntry=adslAtucPerfDataExtEntry, adslAtucThreshold15MinFailedFastR=adslAtucThreshold15MinFailedFastR, adslAtucPerfStatUasL=adslAtucPerfStatUasL, adslExtLineGroup=adslExtLineGroup, adslExtAtucTrapsPrefix=adslExtAtucTrapsPrefix, adslAturPerfCurr15MinUasL=adslAturPerfCurr15MinUasL, adslAtucIntervalSesL=adslAtucIntervalSesL, adslExtLineAlarmConfProfileGroup=adslExtLineAlarmConfProfileGroup, adslAtucPerfCurr1DayFailedFastR=adslAtucPerfCurr1DayFailedFastR, adslAtucPerfCurr15MinUasL=adslAtucPerfCurr15MinUasL, adslAturPerfCurr15MinSesL=adslAturPerfCurr15MinSesL, adslAtucUasLThreshTrap=adslAtucUasLThreshTrap, adslAlarmConfProfileExtEntry=adslAlarmConfProfileExtEntry, adslAtucFailedFastRThreshTrap=adslAtucFailedFastRThreshTrap, adslAturPerfDataExtTable=adslAturPerfDataExtTable, adslAturPerfStatSesL=adslAturPerfStatSesL, adslAturPerfCurr1DaySesL=adslAturPerfCurr1DaySesL, adslExtCompliances=adslExtCompliances, adslAturPerfPrev1DayUasL=adslAturPerfPrev1DayUasL, adslAtucPerfCurr15MinFastR=adslAtucPerfCurr15MinFastR, adslAtucPerfDataExtTable=adslAtucPerfDataExtTable, adslAturPerfPrev1DaySesL=adslAturPerfPrev1DaySesL, adslConfProfileExtEntry=adslConfProfileExtEntry, adslExtMibObjects=adslExtMibObjects, adslExtMIB=adslExtMIB, adslAturPerfCurr1DayUasL=adslAturPerfCurr1DayUasL, adslLineTransAtucConfig=adslLineTransAtucConfig, adslAturIntervalExtTable=adslAturIntervalExtTable, adslAturIntervalSesL=adslAturIntervalSesL, adslExtAturPhysPerfCounterGroup=adslExtAturPhysPerfCounterGroup, adslAtucPerfPrev1DayFastR=adslAtucPerfPrev1DayFastR, adslAtucIntervalExtTable=adslAtucIntervalExtTable, adslExtTraps=adslExtTraps, adslAtucPerfCurr1DayUasL=adslAtucPerfCurr1DayUasL, adslAtucIntervalUasL=adslAtucIntervalUasL, adslAturThreshold15MinSesL=adslAturThreshold15MinSesL, adslExtConformance=adslExtConformance, adslConfProfileExtTable=adslConfProfileExtTable, adslAturIntervalUasL=adslAturIntervalUasL, adslExtAturTraps=adslExtAturTraps, adslLineGlitePowerState=adslLineGlitePowerState, adslConfProfileLineType=adslConfProfileLineType, adslAtucPerfCurr1DayFastR=adslAtucPerfCurr1DayFastR, adslAtucPerfStatFailedFastR=adslAtucPerfStatFailedFastR, adslAtucPerfPrev1DayFailedFastR=adslAtucPerfPrev1DayFailedFastR, adslAtucIntervalExtEntry=adslAtucIntervalExtEntry, adslAtucThreshold15MinUasL=adslAtucThreshold15MinUasL, adslExtGroups=adslExtGroups, adslAturUasLThreshTrap=adslAturUasLThreshTrap, adslAlarmConfProfileExtTable=adslAlarmConfProfileExtTable, adslAturSesLThreshTrap=adslAturSesLThreshTrap, adslAtucPerfCurr15MinSesL=adslAtucPerfCurr15MinSesL, adslLineExtEntry=adslLineExtEntry, adslAtucIntervalFailedFastR=adslAtucIntervalFailedFastR, adslAturPerfStatUasL=adslAturPerfStatUasL, PYSNMP_MODULE_ID=adslExtMIB, AdslTransmissionModeType=AdslTransmissionModeType, adslAtucIntervalFastR=adslAtucIntervalFastR, adslLineConfProfileDualLite=adslLineConfProfileDualLite, adslAtucPerfCurr15MinFailedFastR=adslAtucPerfCurr15MinFailedFastR, adslAtucPerfCurr1DaySesL=adslAtucPerfCurr1DaySesL, adslAturIntervalExtEntry=adslAturIntervalExtEntry, adslAtucThreshold15MinSesL=adslAtucThreshold15MinSesL, adslAturThreshold15MinUasL=adslAturThreshold15MinUasL, adslExtAtucTraps=adslExtAtucTraps, adslAturPerfDataExtEntry=adslAturPerfDataExtEntry, adslExtLineMibAtucCompliance=adslExtLineMibAtucCompliance, adslExtLineConfProfileControlGroup=adslExtLineConfProfileControlGroup, adslAtucPerfPrev1DayUasL=adslAtucPerfPrev1DayUasL, adslExtNotificationsGroup=adslExtNotificationsGroup, adslExtAtucPhysPerfCounterGroup=adslExtAtucPhysPerfCounterGroup, adslAtucSesLThreshTrap=adslAtucSesLThreshTrap)



#
# PySNMP MIB module PIM-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/PIM-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:23:34 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion", "SingleValueConstraint")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ipMRouteNextHopIfIndex, ipMRouteNextHopSource, ipMRouteGroup, ipMRouteNextHopAddress, ipMRouteSourceMask, ipMRouteNextHopGroup, ipMRouteNextHopSourceMask, ipMRouteSource, ) = mibBuilder.importSymbols("IPMROUTE-STD-MIB", "ipMRouteNextHopIfIndex", "ipMRouteNextHopSource", "ipMRouteGroup", "ipMRouteNextHopAddress", "ipMRouteSourceMask", "ipMRouteNextHopGroup", "ipMRouteNextHopSourceMask", "ipMRouteSource")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( ModuleIdentity, iso, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, IpAddress, Integer32, Counter32, Bits, Counter64, Gauge32, MibIdentifier, experimental, ObjectIdentity, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "iso", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "IpAddress", "Integer32", "Counter32", "Bits", "Counter64", "Gauge32", "MibIdentifier", "experimental", "ObjectIdentity", "Unsigned32")
( RowStatus, TruthValue, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TruthValue", "DisplayString", "TextualConvention")
pimMIB = ModuleIdentity((1, 3, 6, 1, 3, 61)).setRevisions(("2000-09-28 00:00",))
if mibBuilder.loadTexts: pimMIB.setLastUpdated('200009280000Z')
if mibBuilder.loadTexts: pimMIB.setOrganization('IETF IDMR Working Group.')
if mibBuilder.loadTexts: pimMIB.setContactInfo(' Dave Thaler\n              Microsoft Corporation\n              One Microsoft Way\n              Redmond, WA  98052-6399\n              US\n\n              Phone: +1 425 703 8835\n              EMail: dthaler@microsoft.com')
if mibBuilder.loadTexts: pimMIB.setDescription('The MIB module for management of PIM routers.')
pimMIBObjects = MibIdentifier((1, 3, 6, 1, 3, 61, 1))
pimTraps = MibIdentifier((1, 3, 6, 1, 3, 61, 1, 0))
pim = MibIdentifier((1, 3, 6, 1, 3, 61, 1, 1))
pimJoinPruneInterval = MibScalar((1, 3, 6, 1, 3, 61, 1, 1, 1), Integer32()).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: pimJoinPruneInterval.setDescription('The default interval at which periodic PIM-SM Join/Prune\n            messages are to be sent.')
pimInterfaceTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 2), )
if mibBuilder.loadTexts: pimInterfaceTable.setDescription("The (conceptual) table listing the router's PIM interfaces.\n            IGMP and PIM are enabled on all interfaces listed in this\n            table.")
pimInterfaceEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 2, 1), ).setIndexNames((0, "PIM-MIB", "pimInterfaceIfIndex"))
if mibBuilder.loadTexts: pimInterfaceEntry.setDescription('An entry (conceptual row) in the pimInterfaceTable.')
pimInterfaceIfIndex = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: pimInterfaceIfIndex.setDescription('The ifIndex value of this PIM interface.')
pimInterfaceAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimInterfaceAddress.setDescription('The IP address of the PIM interface.')
pimInterfaceNetMask = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 3), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimInterfaceNetMask.setDescription('The network mask for the IP address of the PIM interface.')
pimInterfaceMode = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("dense", 1), ("sparse", 2), ("sparseDense", 3),)).clone('dense')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimInterfaceMode.setDescription('The configured mode of this PIM interface.  A value of\n            sparseDense is only valid for PIMv1.')
pimInterfaceDR = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 5), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimInterfaceDR.setDescription('The Designated Router on this PIM interface.  For point-to-\n            point interfaces, this object has the value 0.0.0.0.')
pimInterfaceHelloInterval = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 6), Integer32().clone(30)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimInterfaceHelloInterval.setDescription('The frequency at which PIM Hello messages are transmitted\n            on this interface.')
pimInterfaceStatus = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimInterfaceStatus.setDescription('The status of this entry.  Creating the entry enables PIM\n            on the interface; destroying the entry disables PIM on the\n            interface.')
pimInterfaceJoinPruneInterval = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 8), Integer32()).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimInterfaceJoinPruneInterval.setDescription('The frequency at which PIM Join/Prune messages are\n            transmitted on this PIM interface.  The default value of\n            this object is the pimJoinPruneInterval.')
pimInterfaceCBSRPreference = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 2, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-1,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimInterfaceCBSRPreference.setDescription('The preference value for the local interface as a candidate\n            bootstrap router.  The value of -1 is used to indicate that\n            the local interface is not a candidate BSR interface.')
pimNeighborTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 3), )
if mibBuilder.loadTexts: pimNeighborTable.setDescription("The (conceptual) table listing the router's PIM neighbors.")
pimNeighborEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 3, 1), ).setIndexNames((0, "PIM-MIB", "pimNeighborAddress"))
if mibBuilder.loadTexts: pimNeighborEntry.setDescription('An entry (conceptual row) in the pimNeighborTable.')
pimNeighborAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 3, 1, 1), IpAddress())
if mibBuilder.loadTexts: pimNeighborAddress.setDescription('The IP address of the PIM neighbor for which this entry\n            contains information.')
pimNeighborIfIndex = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 3, 1, 2), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimNeighborIfIndex.setDescription('The value of ifIndex for the interface used to reach this\n            PIM neighbor.')
pimNeighborUpTime = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 3, 1, 3), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimNeighborUpTime.setDescription('The time since this PIM neighbor (last) became a neighbor\n            of the local router.')
pimNeighborExpiryTime = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 3, 1, 4), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimNeighborExpiryTime.setDescription('The minimum time remaining before this PIM neighbor will be\n            aged out.')
pimNeighborMode = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 3, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("dense", 1), ("sparse", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimNeighborMode.setDescription('The active PIM mode of this neighbor.  This object is\n            deprecated for PIMv2 routers since all neighbors on the\n            interface must be either dense or sparse as determined by\n            the protocol running on the interface.')
pimIpMRouteTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 4), )
if mibBuilder.loadTexts: pimIpMRouteTable.setDescription('The (conceptual) table listing PIM-specific information on\n            a subset of the rows of the ipMRouteTable defined in the IP\n            Multicast MIB.')
pimIpMRouteEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 4, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteGroup"), (0, "IPMROUTE-STD-MIB", "ipMRouteSource"), (0, "IPMROUTE-STD-MIB", "ipMRouteSourceMask"))
if mibBuilder.loadTexts: pimIpMRouteEntry.setDescription('An entry (conceptual row) in the pimIpMRouteTable.  There\n            is one entry per entry in the ipMRouteTable whose incoming\n            interface is running PIM.')
pimIpMRouteUpstreamAssertTimer = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 4, 1, 1), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimIpMRouteUpstreamAssertTimer.setDescription('The time remaining before the router changes its upstream\n            neighbor back to its RPF neighbor.  This timer is called the\n            Assert timer in the PIM Sparse and Dense mode specification.\n            A value of 0 indicates that no Assert has changed the\n            upstream neighbor away from the RPF neighbor.')
pimIpMRouteAssertMetric = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 4, 1, 2), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimIpMRouteAssertMetric.setDescription('The metric advertised by the assert winner on the upstream\n            interface, or 0 if no such assert is in received.')
pimIpMRouteAssertMetricPref = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 4, 1, 3), Integer32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimIpMRouteAssertMetricPref.setDescription('The preference advertised by the assert winner on the\n            upstream interface, or 0 if no such assert is in effect.')
pimIpMRouteAssertRPTBit = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 4, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimIpMRouteAssertRPTBit.setDescription('The value of the RPT-bit advertised by the assert winner on\n            the upstream interface, or false if no such assert is in\n            effect.')
pimIpMRouteFlags = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 4, 1, 5), Bits().clone(namedValues=NamedValues(("rpt", 0), ("spt", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimIpMRouteFlags.setDescription('This object describes PIM-specific flags related to a\n            multicast state entry.  See the PIM Sparse Mode\n            specification for the meaning of the RPT and SPT bits.')
pimIpMRouteNextHopTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 7), )
if mibBuilder.loadTexts: pimIpMRouteNextHopTable.setDescription('The (conceptual) table listing PIM-specific information on\n            a subset of the rows of the ipMRouteNextHopTable defined in\n            the IP Multicast MIB.')
pimIpMRouteNextHopEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 7, 1), ).setIndexNames((0, "IPMROUTE-STD-MIB", "ipMRouteNextHopGroup"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopSource"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopSourceMask"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopIfIndex"), (0, "IPMROUTE-STD-MIB", "ipMRouteNextHopAddress"))
if mibBuilder.loadTexts: pimIpMRouteNextHopEntry.setDescription('An entry (conceptual row) in the pimIpMRouteNextHopTable.\n            There is one entry per entry in the ipMRouteNextHopTable\n            whose interface is running PIM and whose\n            ipMRouteNextHopState is pruned(1).')
pimIpMRouteNextHopPruneReason = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 7, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("other", 1), ("prune", 2), ("assert", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimIpMRouteNextHopPruneReason.setDescription('This object indicates why the downstream interface was\n            pruned, whether in response to a PIM prune message or due to\n            PIM Assert processing.')
pimRPTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 5), )
if mibBuilder.loadTexts: pimRPTable.setDescription('The (conceptual) table listing PIM version 1 information\n            for the Rendezvous Points (RPs) for IP multicast groups.\n            This table is deprecated since its function is replaced by\n            the pimRPSetTable for PIM version 2.')
pimRPEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 5, 1), ).setIndexNames((0, "PIM-MIB", "pimRPGroupAddress"), (0, "PIM-MIB", "pimRPAddress"))
if mibBuilder.loadTexts: pimRPEntry.setDescription('An entry (conceptual row) in the pimRPTable.  There is one\n            entry per RP address for each IP multicast group.')
pimRPGroupAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 5, 1, 1), IpAddress())
if mibBuilder.loadTexts: pimRPGroupAddress.setDescription('The IP multicast group address for which this entry\n            contains information about an RP.')
pimRPAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 5, 1, 2), IpAddress())
if mibBuilder.loadTexts: pimRPAddress.setDescription('The unicast address of the RP.')
pimRPState = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 5, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimRPState.setDescription('The state of the RP.')
pimRPStateTimer = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 5, 1, 4), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimRPStateTimer.setDescription('The minimum time remaining before the next state change.\n            When pimRPState is up, this is the minimum time which must\n            expire until it can be declared down.  When pimRPState is\n            down, this is the time until it will be declared up (in\n            order to retry).')
pimRPLastChange = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 5, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimRPLastChange.setDescription('The value of sysUpTime at the time when the corresponding\n            instance of pimRPState last changed its value.')
pimRPRowStatus = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 5, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimRPRowStatus.setDescription('The status of this row, by which new entries may be\n            created, or old entries deleted from this table.')
pimRPSetTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 6), )
if mibBuilder.loadTexts: pimRPSetTable.setDescription('The (conceptual) table listing PIM information for\n            candidate Rendezvous Points (RPs) for IP multicast groups.\n            When the local router is the BSR, this information is\n            obtained from received Candidate-RP-Advertisements.  When\n            the local router is not the BSR, this information is\n            obtained from received RP-Set messages.')
pimRPSetEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 6, 1), ).setIndexNames((0, "PIM-MIB", "pimRPSetComponent"), (0, "PIM-MIB", "pimRPSetGroupAddress"), (0, "PIM-MIB", "pimRPSetGroupMask"), (0, "PIM-MIB", "pimRPSetAddress"))
if mibBuilder.loadTexts: pimRPSetEntry.setDescription('An entry (conceptual row) in the pimRPSetTable.')
pimRPSetGroupAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 6, 1, 1), IpAddress())
if mibBuilder.loadTexts: pimRPSetGroupAddress.setDescription('The IP multicast group address which, when combined with\n            pimRPSetGroupMask, gives the group prefix for which this\n            entry contains information about the Candidate-RP.')
pimRPSetGroupMask = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 6, 1, 2), IpAddress())
if mibBuilder.loadTexts: pimRPSetGroupMask.setDescription('The multicast group address mask which, when combined with\n            pimRPSetGroupAddress, gives the group prefix for which this\n            entry contains information about the Candidate-RP.')
pimRPSetAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 6, 1, 3), IpAddress())
if mibBuilder.loadTexts: pimRPSetAddress.setDescription('The IP address of the Candidate-RP.')
pimRPSetHoldTime = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 6, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: pimRPSetHoldTime.setDescription('The holdtime of a Candidate-RP.  If the local router is not\n            the BSR, this value is 0.')
pimRPSetExpiryTime = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 6, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimRPSetExpiryTime.setDescription('The minimum time remaining before the Candidate-RP will be\n            declared down.  If the local router is not the BSR, this\n            value is 0.')
pimRPSetComponent = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 6, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255)))
if mibBuilder.loadTexts: pimRPSetComponent.setDescription(' A number uniquely identifying the component.  Each\n            protocol instance connected to a separate domain should have\n            a different index value.')
pimCandidateRPTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 11), )
if mibBuilder.loadTexts: pimCandidateRPTable.setDescription('The (conceptual) table listing the IP multicast groups for\n            which the local router is to advertise itself as a\n            Candidate-RP when the value of pimComponentCRPHoldTime is\n            non-zero.  If this table is empty, then the local router\n            will advertise itself as a Candidate-RP for all groups\n            (providing the value of pimComponentCRPHoldTime is non-\n            zero).')
pimCandidateRPEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 11, 1), ).setIndexNames((0, "PIM-MIB", "pimCandidateRPGroupAddress"), (0, "PIM-MIB", "pimCandidateRPGroupMask"))
if mibBuilder.loadTexts: pimCandidateRPEntry.setDescription('An entry (conceptual row) in the pimCandidateRPTable.')
pimCandidateRPGroupAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 11, 1, 1), IpAddress())
if mibBuilder.loadTexts: pimCandidateRPGroupAddress.setDescription('The IP multicast group address which, when combined with\n            pimCandidateRPGroupMask, identifies a group prefix for which\n            the local router will advertise itself as a Candidate-RP.')
pimCandidateRPGroupMask = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 11, 1, 2), IpAddress())
if mibBuilder.loadTexts: pimCandidateRPGroupMask.setDescription('The multicast group address mask which, when combined with\n            pimCandidateRPGroupMask, identifies a group prefix for which\n            the local router will advertise itself as a Candidate-RP.')
pimCandidateRPAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 11, 1, 3), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimCandidateRPAddress.setDescription('The (unicast) address of the interface which will be\n            advertised as a Candidate-RP.')
pimCandidateRPRowStatus = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 11, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimCandidateRPRowStatus.setDescription('The status of this row, by which new entries may be\n            created, or old entries deleted from this table.')
pimComponentTable = MibTable((1, 3, 6, 1, 3, 61, 1, 1, 12), )
if mibBuilder.loadTexts: pimComponentTable.setDescription('The (conceptual) table containing objects specific to a PIM\n            domain.  One row exists for each domain to which the router\n            is connected.  A PIM-SM domain is defined as an area of the\n            network over which Bootstrap messages are forwarded.\n            Typically, a PIM-SM router will be a member of exactly one\n            domain.  This table also supports, however, routers which\n            may form a border between two PIM-SM domains and do not\n            forward Bootstrap messages between them.')
pimComponentEntry = MibTableRow((1, 3, 6, 1, 3, 61, 1, 1, 12, 1), ).setIndexNames((0, "PIM-MIB", "pimComponentIndex"))
if mibBuilder.loadTexts: pimComponentEntry.setDescription('An entry (conceptual row) in the pimComponentTable.')
pimComponentIndex = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 12, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,255)))
if mibBuilder.loadTexts: pimComponentIndex.setDescription('A number uniquely identifying the component.  Each protocol\n            instance connected to a separate domain should have a\n            different index value.  Routers that only support membership\n            in a single PIM-SM domain should use a pimComponentIndex\n            value of 1.')
pimComponentBSRAddress = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 12, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimComponentBSRAddress.setDescription('The IP address of the bootstrap router (BSR) for the local\n            PIM region.')
pimComponentBSRExpiryTime = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 12, 1, 3), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pimComponentBSRExpiryTime.setDescription('The minimum time remaining before the bootstrap router in\n            the local domain will be declared down.  For candidate BSRs,\n            this is the time until the component sends an RP-Set\n            message.  For other routers, this is the time until it may\n            accept an RP-Set message from a lower candidate BSR.')
pimComponentCRPHoldTime = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 12, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimComponentCRPHoldTime.setDescription('The holdtime of the component when it is a candidate RP in\n            the local domain.  The value of 0 is used to indicate that\n            the local system is not a Candidate-RP.')
pimComponentStatus = MibTableColumn((1, 3, 6, 1, 3, 61, 1, 1, 12, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: pimComponentStatus.setDescription('The status of this entry.  Creating the entry creates\n            another protocol instance; destroying the entry disables a\n            protocol instance.')
pimNeighborLoss = NotificationType((1, 3, 6, 1, 3, 61, 1, 0, 1)).setObjects(*(("PIM-MIB", "pimNeighborIfIndex"),))
if mibBuilder.loadTexts: pimNeighborLoss.setDescription('A pimNeighborLoss trap signifies the loss of an adjacency\n            with a neighbor.  This trap should be generated when the\n            neighbor timer expires, and the router has no other\n            neighbors on the same interface with a lower IP address than\n            itself.')
pimMIBConformance = MibIdentifier((1, 3, 6, 1, 3, 61, 2))
pimMIBCompliances = MibIdentifier((1, 3, 6, 1, 3, 61, 2, 1))
pimMIBGroups = MibIdentifier((1, 3, 6, 1, 3, 61, 2, 2))
pimV1MIBCompliance = ModuleCompliance((1, 3, 6, 1, 3, 61, 2, 1, 1)).setObjects(*(("PIM-MIB", "pimV1MIBGroup"),))
if mibBuilder.loadTexts: pimV1MIBCompliance.setDescription('The compliance statement for routers running PIMv1 and\n            implementing the PIM MIB.')
pimSparseV2MIBCompliance = ModuleCompliance((1, 3, 6, 1, 3, 61, 2, 1, 2)).setObjects(*(("PIM-MIB", "pimV2MIBGroup"), ("PIM-MIB", "pimV2CandidateRPMIBGroup"),))
if mibBuilder.loadTexts: pimSparseV2MIBCompliance.setDescription('The compliance statement for routers running PIM Sparse\n            Mode and implementing the PIM MIB.')
pimDenseV2MIBCompliance = ModuleCompliance((1, 3, 6, 1, 3, 61, 2, 1, 3)).setObjects(*(("PIM-MIB", "pimDenseV2MIBGroup"),))
if mibBuilder.loadTexts: pimDenseV2MIBCompliance.setDescription('The compliance statement for routers running PIM Dense Mode\n            and implementing the PIM MIB.')
pimNotificationGroup = NotificationGroup((1, 3, 6, 1, 3, 61, 2, 2, 1)).setObjects(*(("PIM-MIB", "pimNeighborLoss"),))
if mibBuilder.loadTexts: pimNotificationGroup.setDescription('A collection of notifications for signaling important PIM\n            events.')
pimV2MIBGroup = ObjectGroup((1, 3, 6, 1, 3, 61, 2, 2, 2)).setObjects(*(("PIM-MIB", "pimJoinPruneInterval"), ("PIM-MIB", "pimNeighborIfIndex"), ("PIM-MIB", "pimNeighborUpTime"), ("PIM-MIB", "pimNeighborExpiryTime"), ("PIM-MIB", "pimInterfaceAddress"), ("PIM-MIB", "pimInterfaceNetMask"), ("PIM-MIB", "pimInterfaceDR"), ("PIM-MIB", "pimInterfaceHelloInterval"), ("PIM-MIB", "pimInterfaceStatus"), ("PIM-MIB", "pimInterfaceJoinPruneInterval"), ("PIM-MIB", "pimInterfaceCBSRPreference"), ("PIM-MIB", "pimInterfaceMode"), ("PIM-MIB", "pimRPSetHoldTime"), ("PIM-MIB", "pimRPSetExpiryTime"), ("PIM-MIB", "pimComponentBSRAddress"), ("PIM-MIB", "pimComponentBSRExpiryTime"), ("PIM-MIB", "pimComponentCRPHoldTime"), ("PIM-MIB", "pimComponentStatus"), ("PIM-MIB", "pimIpMRouteFlags"), ("PIM-MIB", "pimIpMRouteUpstreamAssertTimer"),))
if mibBuilder.loadTexts: pimV2MIBGroup.setDescription('A collection of objects to support management of PIM Sparse\n            Mode (version 2) routers.')
pimDenseV2MIBGroup = ObjectGroup((1, 3, 6, 1, 3, 61, 2, 2, 5)).setObjects(*(("PIM-MIB", "pimNeighborIfIndex"), ("PIM-MIB", "pimNeighborUpTime"), ("PIM-MIB", "pimNeighborExpiryTime"), ("PIM-MIB", "pimInterfaceAddress"), ("PIM-MIB", "pimInterfaceNetMask"), ("PIM-MIB", "pimInterfaceDR"), ("PIM-MIB", "pimInterfaceHelloInterval"), ("PIM-MIB", "pimInterfaceStatus"), ("PIM-MIB", "pimInterfaceMode"),))
if mibBuilder.loadTexts: pimDenseV2MIBGroup.setDescription('A collection of objects to support management of PIM Dense\n            Mode (version 2) routers.')
pimV2CandidateRPMIBGroup = ObjectGroup((1, 3, 6, 1, 3, 61, 2, 2, 3)).setObjects(*(("PIM-MIB", "pimCandidateRPAddress"), ("PIM-MIB", "pimCandidateRPRowStatus"),))
if mibBuilder.loadTexts: pimV2CandidateRPMIBGroup.setDescription('A collection of objects to support configuration of which\n            groups a router is to advertise itself as a Candidate-RP.')
pimV1MIBGroup = ObjectGroup((1, 3, 6, 1, 3, 61, 2, 2, 4)).setObjects(*(("PIM-MIB", "pimJoinPruneInterval"), ("PIM-MIB", "pimNeighborIfIndex"), ("PIM-MIB", "pimNeighborUpTime"), ("PIM-MIB", "pimNeighborExpiryTime"), ("PIM-MIB", "pimNeighborMode"), ("PIM-MIB", "pimInterfaceAddress"), ("PIM-MIB", "pimInterfaceNetMask"), ("PIM-MIB", "pimInterfaceJoinPruneInterval"), ("PIM-MIB", "pimInterfaceStatus"), ("PIM-MIB", "pimInterfaceMode"), ("PIM-MIB", "pimInterfaceDR"), ("PIM-MIB", "pimInterfaceHelloInterval"), ("PIM-MIB", "pimRPState"), ("PIM-MIB", "pimRPStateTimer"), ("PIM-MIB", "pimRPLastChange"), ("PIM-MIB", "pimRPRowStatus"),))
if mibBuilder.loadTexts: pimV1MIBGroup.setDescription('A collection of objects to support management of PIM\n            (version 1) routers.')
pimNextHopGroup = ObjectGroup((1, 3, 6, 1, 3, 61, 2, 2, 6)).setObjects(*(("PIM-MIB", "pimIpMRouteNextHopPruneReason"),))
if mibBuilder.loadTexts: pimNextHopGroup.setDescription('A collection of optional objects to provide per-next hop\n            information for diagnostic purposes.  Supporting this group\n            may add a large number of instances to a tree walk, but the\n            information in this group can be extremely useful in\n            tracking down multicast connectivity problems.')
pimAssertGroup = ObjectGroup((1, 3, 6, 1, 3, 61, 2, 2, 7)).setObjects(*(("PIM-MIB", "pimIpMRouteAssertMetric"), ("PIM-MIB", "pimIpMRouteAssertMetricPref"), ("PIM-MIB", "pimIpMRouteAssertRPTBit"),))
if mibBuilder.loadTexts: pimAssertGroup.setDescription('A collection of optional objects to provide extra\n            information about the assert election process.  There is no\n            protocol reason to keep such information, but some\n            implementations may already keep this information and make\n            it available.  These objects can also be very useful in\n            debugging connectivity or duplicate packet problems,\n            especially if the assert winner does not support the PIM and\n            IP Multicast MIBs.')
mibBuilder.exportSymbols("PIM-MIB", pimInterfaceDR=pimInterfaceDR, pimMIBObjects=pimMIBObjects, pimDenseV2MIBGroup=pimDenseV2MIBGroup, pimRPEntry=pimRPEntry, pimInterfaceHelloInterval=pimInterfaceHelloInterval, pimIpMRouteEntry=pimIpMRouteEntry, pimRPSetGroupMask=pimRPSetGroupMask, pimRPAddress=pimRPAddress, pimMIB=pimMIB, pimNeighborEntry=pimNeighborEntry, pimIpMRouteAssertRPTBit=pimIpMRouteAssertRPTBit, pimIpMRouteFlags=pimIpMRouteFlags, pimRPSetEntry=pimRPSetEntry, pimInterfaceAddress=pimInterfaceAddress, pimInterfaceEntry=pimInterfaceEntry, pimNotificationGroup=pimNotificationGroup, pimV2MIBGroup=pimV2MIBGroup, pimMIBGroups=pimMIBGroups, pimV1MIBGroup=pimV1MIBGroup, pimAssertGroup=pimAssertGroup, pimComponentTable=pimComponentTable, pimNeighborExpiryTime=pimNeighborExpiryTime, pimTraps=pimTraps, pimNeighborMode=pimNeighborMode, pimNeighborAddress=pimNeighborAddress, pimRPGroupAddress=pimRPGroupAddress, pimRPSetExpiryTime=pimRPSetExpiryTime, pimCandidateRPGroupMask=pimCandidateRPGroupMask, pimIpMRouteUpstreamAssertTimer=pimIpMRouteUpstreamAssertTimer, pimNeighborIfIndex=pimNeighborIfIndex, pimInterfaceNetMask=pimInterfaceNetMask, pimNeighborUpTime=pimNeighborUpTime, pimRPRowStatus=pimRPRowStatus, pimRPSetGroupAddress=pimRPSetGroupAddress, pimNeighborTable=pimNeighborTable, pimNeighborLoss=pimNeighborLoss, pimInterfaceTable=pimInterfaceTable, pimIpMRouteNextHopPruneReason=pimIpMRouteNextHopPruneReason, pimV2CandidateRPMIBGroup=pimV2CandidateRPMIBGroup, pimJoinPruneInterval=pimJoinPruneInterval, pimCandidateRPTable=pimCandidateRPTable, pimInterfaceCBSRPreference=pimInterfaceCBSRPreference, pimComponentIndex=pimComponentIndex, pimInterfaceIfIndex=pimInterfaceIfIndex, pimRPSetComponent=pimRPSetComponent, pimNextHopGroup=pimNextHopGroup, pimRPLastChange=pimRPLastChange, pimRPState=pimRPState, pimRPSetAddress=pimRPSetAddress, pimCandidateRPAddress=pimCandidateRPAddress, pimRPTable=pimRPTable, pimIpMRouteNextHopEntry=pimIpMRouteNextHopEntry, pimSparseV2MIBCompliance=pimSparseV2MIBCompliance, pimRPStateTimer=pimRPStateTimer, pimCandidateRPRowStatus=pimCandidateRPRowStatus, pimInterfaceMode=pimInterfaceMode, pimComponentBSRExpiryTime=pimComponentBSRExpiryTime, pimInterfaceStatus=pimInterfaceStatus, pimIpMRouteAssertMetricPref=pimIpMRouteAssertMetricPref, pimIpMRouteNextHopTable=pimIpMRouteNextHopTable, pimMIBCompliances=pimMIBCompliances, pimComponentStatus=pimComponentStatus, pimIpMRouteAssertMetric=pimIpMRouteAssertMetric, pimDenseV2MIBCompliance=pimDenseV2MIBCompliance, pimMIBConformance=pimMIBConformance, pimRPSetHoldTime=pimRPSetHoldTime, pimV1MIBCompliance=pimV1MIBCompliance, pimIpMRouteTable=pimIpMRouteTable, pimComponentCRPHoldTime=pimComponentCRPHoldTime, pim=pim, pimCandidateRPEntry=pimCandidateRPEntry, pimInterfaceJoinPruneInterval=pimInterfaceJoinPruneInterval, pimComponentEntry=pimComponentEntry, pimCandidateRPGroupAddress=pimCandidateRPGroupAddress, pimComponentBSRAddress=pimComponentBSRAddress, PYSNMP_MODULE_ID=pimMIB, pimRPSetTable=pimRPSetTable)



#
# PySNMP MIB module SIP-UA-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SIP-UA-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:28:20 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( applIndex, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "applIndex")
( sipMIB, ) = mibBuilder.importSymbols("SIP-MIB-SMI", "sipMIB")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( MibIdentifier, Bits, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, ObjectIdentity, Counter64, iso, ModuleIdentity, NotificationType, Gauge32, IpAddress, TimeTicks, Unsigned32, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "Bits", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "ObjectIdentity", "Counter64", "iso", "ModuleIdentity", "NotificationType", "Gauge32", "IpAddress", "TimeTicks", "Unsigned32", "Counter32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
sipUAMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 9998, 3))
if mibBuilder.loadTexts: sipUAMIB.setLastUpdated('200007080000Z')
if mibBuilder.loadTexts: sipUAMIB.setOrganization('IETF SIP Working Group, SIP MIB Team')
if mibBuilder.loadTexts: sipUAMIB.setContactInfo('SIP MIB Team email: sip-mib@egroups.com \n\n                 Co-editor  Kevin Lingle \n                            Cisco Systems, Inc. \n                 postal:    7025 Kit Creek Road \n                            P.O. Box 14987 \n                            Research Triangle Park, NC 27709 \n                            USA \n                 email:     klingle@cisco.com \n                 phone:     +1-919-392-2029 \n\n                 Co-editor  Joon Maeng \n                            VTEL Corporation \n                 postal:    108 Wild Basin Rd. \n                            Austin, TX 78746 \n                            USA \n                 email:     joon_maeng@vtel.com \n                 phone:     +1-512-437-4567 \n\n                 Co-editor  Dave Walker \n                            SS8 Networks, Inc. \n                 postal:    80 Hines Road \n                            Kanata, ON  K2K 2T8 \n                            Canada \n                 email:     drwalker@ss8networks.com \n                 phone:     +1 613 592 2100')
if mibBuilder.loadTexts: sipUAMIB.setDescription('Initial version of Session Initiation Protocol (SIP) \n                 User Agent (UA) MIB module. \n\n                 SIP is an application-layer signalling protocol for  \n                 creating, modifying and terminating multimedia  \n                 sessions with one or more participants. These sessions \n                 include Internet multimedia conferences and Internet  \n                 telephone calls.  SIP is defined in RFC 2543 (March  \n                 1999). \n\n                 A User Agent is an application that contains both a \n                 User Agent Client (UAC) and a User Agent Server (UAS). \n                 A UAC is an application that initiates a SIP request. \n                 A UAS is an application that contacts the user when a \n                 SIP request is received and that returns a response on \n                 behalf of the user.  The response accepts, rejects, or \n                 redirects the request.')
sipUACfg = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 1))
sipUACfgTimer = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1))
sipUACfgRetry = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2))
sipUAStats = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 2))
sipUAStatsRetry = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1))
sipUACfgTimerTable = MibTable((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1), )
if mibBuilder.loadTexts: sipUACfgTimerTable.setDescription('This table contains timer configuration objects applicable  \n             to each SIP user agent in this system.  The instances of  \n             SIP entities are uniquely identified by applIndex.')
sipUACfgTimerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: sipUACfgTimerEntry.setDescription('A row of timer configuration.')
sipUACfgTimerTrying = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerTrying.setDescription('This object specifies the time a user agent will wait to \n             receive a provisional response to an INVITE before \n             resending the INVITE.')
sipUACfgTimerProv = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(60000,300000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerProv.setDescription('This object specifies the time a user agent will wait to \n             receive a final response to an INVITE before canceling the \n             transaction.')
sipUACfgTimerAck = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerAck.setDescription('This object specifies the time a user agent will wait to \n             receive an ACK confirmation indicating that a session is \n             established.')
sipUACfgTimerDisconnect = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(100,1000))).setUnits('milliseconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerDisconnect.setDescription('This object specifies the time a user agent will wait to \n             receive a BYE confirmation indicating that a session is \n             disconnected.')
sipUACfgTimerReRegister = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgTimerReRegister.setDescription('This object specifies how long the user agent wishes its \n             registrations to be valid.')
sipUACfgRetryTable = MibTable((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1), )
if mibBuilder.loadTexts: sipUACfgRetryTable.setDescription('This table contains retry configuration objects applicable  \n             to each SIP user agent in this system.  The instances of  \n             SIP entities are uniquely identified by applIndex.')
sipUACfgRetryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: sipUACfgRetryEntry.setDescription('A row of retry configuration.')
sipUACfgRetryInvite = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryInvite.setDescription('This object will specify the number of times a user agent \n             will retry sending an INVITE request.')
sipUACfgRetryBye = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryBye.setDescription('This object will specify the number of times a user agent \n             will retry sending a BYE request.')
sipUACfgRetryCancel = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryCancel.setDescription('This object will specify the number of times a user agent \n             will retry sending a CANCEL request.')
sipUACfgRetryRegister = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryRegister.setDescription('This object will specify the number of times a user agent \n             will retry sending a REGISTER request.')
sipUACfgRetryResponse = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 1, 2, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sipUACfgRetryResponse.setDescription('This object will specify the number of times a user agent \n             will retry sending a Response and expecting an ACK.')
sipUAStatsRetryTable = MibTable((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1), )
if mibBuilder.loadTexts: sipUAStatsRetryTable.setDescription('This table contains retry statistics objects applicable  \n             to each SIP user agent in this system.  The instances of  \n             SIP entities are uniquely identified by applIndex.')
sipUAStatsRetryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: sipUAStatsRetryEntry.setDescription('A row of retry statistics.')
sipStatsRetryInvites = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryInvites.setDescription("This object reflects the total number of INVITE retries \n             that have been sent by the user agent.   If the number of \n             'first attempt' INVITES is of interest, subtract the value \n             of this object from sipStatsTrafficInviteOut.")
sipStatsRetryByes = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryByes.setDescription('This object reflects the total number of BYE retries that \n             have been sent by the user agent.')
sipStatsRetryCancels = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryCancels.setDescription('This object reflects the total number of CANCEL retries \n             that have been sent by the user agent.')
sipStatsRetryRegisters = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryRegisters.setDescription('This object reflects the total number of REGISTER retries \n             that have been sent by the user agent.')
sipStatsRetryResponses = MibTableColumn((1, 3, 6, 1, 2, 1, 9998, 3, 2, 1, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sipStatsRetryResponses.setDescription('This object reflects the total number of Response (while \n             expecting an ACK) retries that have been sent by the user \n             agent.')
sipUAMIBNotif = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 3))
sipUAMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 4))
sipUAMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 4, 1))
sipUAMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 9998, 3, 4, 2))
sipUACompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 9998, 3, 4, 1, 1)).setObjects(*(("SIP-UA-MIB", "sipUAConfigGroup"), ("SIP-UA-MIB", "sipUAStatsGroup"),))
if mibBuilder.loadTexts: sipUACompliance.setDescription('The compliance statement for SIP entities.')
sipUAConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 9998, 3, 4, 2, 1)).setObjects(*(("SIP-UA-MIB", "sipUACfgTimerTrying"), ("SIP-UA-MIB", "sipUACfgTimerProv"), ("SIP-UA-MIB", "sipUACfgTimerAck"), ("SIP-UA-MIB", "sipUACfgTimerDisconnect"), ("SIP-UA-MIB", "sipUACfgTimerReRegister"), ("SIP-UA-MIB", "sipUACfgRetryInvite"), ("SIP-UA-MIB", "sipUACfgRetryBye"), ("SIP-UA-MIB", "sipUACfgRetryCancel"), ("SIP-UA-MIB", "sipUACfgRetryRegister"), ("SIP-UA-MIB", "sipUACfgRetryResponse"),))
if mibBuilder.loadTexts: sipUAConfigGroup.setDescription('A collection of objects providing configuration for \n             SIP User Agents.')
sipUAStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 9998, 3, 4, 2, 2)).setObjects(*(("SIP-UA-MIB", "sipStatsRetryInvites"), ("SIP-UA-MIB", "sipStatsRetryByes"), ("SIP-UA-MIB", "sipStatsRetryCancels"), ("SIP-UA-MIB", "sipStatsRetryRegisters"), ("SIP-UA-MIB", "sipStatsRetryResponses"),))
if mibBuilder.loadTexts: sipUAStatsGroup.setDescription('A collection of objects providing statistics for \n             SIP User Agents.')
mibBuilder.exportSymbols("SIP-UA-MIB", PYSNMP_MODULE_ID=sipUAMIB, sipStatsRetryInvites=sipStatsRetryInvites, sipUACfgTimerTrying=sipUACfgTimerTrying, sipUACfgTimerAck=sipUACfgTimerAck, sipUAMIBNotif=sipUAMIBNotif, sipUACfgRetryEntry=sipUACfgRetryEntry, sipUACfgRetryCancel=sipUACfgRetryCancel, sipUAMIBCompliances=sipUAMIBCompliances, sipUAMIBGroups=sipUAMIBGroups, sipStatsRetryRegisters=sipStatsRetryRegisters, sipUAStatsRetryTable=sipUAStatsRetryTable, sipUAMIB=sipUAMIB, sipUACfgTimerDisconnect=sipUACfgTimerDisconnect, sipStatsRetryCancels=sipStatsRetryCancels, sipStatsRetryResponses=sipStatsRetryResponses, sipUACfgRetryBye=sipUACfgRetryBye, sipUAStatsRetry=sipUAStatsRetry, sipUACfgTimer=sipUACfgTimer, sipUACfgTimerProv=sipUACfgTimerProv, sipUACfgTimerEntry=sipUACfgTimerEntry, sipUAStatsRetryEntry=sipUAStatsRetryEntry, sipUACfg=sipUACfg, sipUACfgRetryInvite=sipUACfgRetryInvite, sipUACfgRetryRegister=sipUACfgRetryRegister, sipUAStatsGroup=sipUAStatsGroup, sipUACfgTimerReRegister=sipUACfgTimerReRegister, sipUACfgRetryResponse=sipUACfgRetryResponse, sipUAConfigGroup=sipUAConfigGroup, sipUACfgRetryTable=sipUACfgRetryTable, sipUAMIBConformance=sipUAMIBConformance, sipUACompliance=sipUACompliance, sipUACfgRetry=sipUACfgRetry, sipStatsRetryByes=sipStatsRetryByes, sipUAStats=sipUAStats, sipUACfgTimerTable=sipUACfgTimerTable)
